#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
uniform sampler2D u_texture;
uniform float u_brightness;
uniform float u_saturation;
uniform float u_contrast;

/*
** Contrast, saturation, brightness
** Code of this function is from TGM's shader pack
** http://irrlicht.sourceforge.net/phpBB2/viewtopic.php?t=21057
*/

// For all settings: 1.0 = 100% 0.5=50% 1.5 = 150%
vec3 ContrastSaturationBrightness(vec3 color, float brt, float sat, float con)
{
	// Increase or decrease theese values to adjust r, g and b color channels seperately
	const float AvgLumR = 0.5;
	const float AvgLumG = 0.5;
	const float AvgLumB = 0.5;

	const vec3 LumCoeff = vec3(0.2125, 0.7154, 0.0721);

	vec3 AvgLumin = vec3(AvgLumR, AvgLumG, AvgLumB);
	vec3 brtColor = color * brt;
	vec3 intensity = vec3(dot(brtColor, LumCoeff));
	vec3 satColor = mix(intensity, brtColor, sat);
	vec3 conColor = mix(AvgLumin, satColor, con);
	return conColor;
}


void main() 
{
	vec4 color = texture2D(u_texture, v_texCoord);

	// Optimization: do not go into ContrastSaturationBrightness() if we're not changing
	// any value! (brightness, saturation and contrast are all set at 1.0)
	vec4 resColor;
	vec3 settings = vec3(u_brightness, u_saturation, u_contrast);
	if (settings != vec3(1.0, 1.0, 1.0))
	{
		vec3 treatedColor = ContrastSaturationBrightness(vec3(color.r, color.g, color.b), u_brightness, u_saturation, u_contrast);
		resColor = vec4(treatedColor.r, treatedColor.g, treatedColor.b, color.a);
	}
	else
		resColor = color;

	gl_FragColor = v_fragmentColor * vec4(resColor.r, resColor.g, resColor.b, resColor.a);
	
}